package com.ruoyi.model.mapper;

import java.util.List;
import com.ruoyi.model.domain.AddValueService;

/**
 * 增值服务Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-06
 */
public interface AddValueServiceMapper 
{
    /**
     * 查询增值服务
     * 
     * @param addValueServiceId 增值服务主键
     * @return 增值服务
     */
    public AddValueService selectAddValueServiceByAddValueServiceId(Long addValueServiceId);

    /**
     * 查询增值服务列表
     * 
     * @param addValueService 增值服务
     * @return 增值服务集合
     */
    public List<AddValueService> selectAddValueServiceList(AddValueService addValueService);

    /**
     * 新增增值服务
     * 
     * @param addValueService 增值服务
     * @return 结果
     */
    public int insertAddValueService(AddValueService addValueService);

    /**
     * 修改增值服务
     * 
     * @param addValueService 增值服务
     * @return 结果
     */
    public int updateAddValueService(AddValueService addValueService);

    /**
     * 删除增值服务
     * 
     * @param addValueServiceId 增值服务主键
     * @return 结果
     */
    public int deleteAddValueServiceByAddValueServiceId(Long addValueServiceId);

    /**
     * 批量删除增值服务
     * 
     * @param addValueServiceIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAddValueServiceByAddValueServiceIds(Long[] addValueServiceIds);

    /**
     * 查询增值服务列表
     *
     * @return 增值服务集合
     */
    public List<AddValueService> getAddValueServiceList();
}
